Class: MailSlurpClient::CreatePhoneNumberOptions
- Inherits:
-
Object
- Object
- MailSlurpClient::CreatePhoneNumberOptions
- Defined in:
- lib/mailslurp_client/models/create_phone_number_options.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#description ⇒ Object
Returns the value of attribute description.
-
#name ⇒ Object
Returns the value of attribute name.
-
#phone_country ⇒ Object
Returns the value of attribute phone_country.
-
#phone_line_filter ⇒ Object
Line-quality preference for simple phone number provisioning.
-
#phone_number_endpoint_override ⇒ Object
Returns the value of attribute phone_number_endpoint_override.
-
#phone_number_variant ⇒ Object
Returns the value of attribute phone_number_variant.
-
#phone_provider ⇒ Object
Returns the value of attribute phone_provider.
-
#schedule ⇒ Object
Returns the value of attribute schedule.
-
#tags ⇒ Object
Returns the value of attribute tags.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreatePhoneNumberOptions
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreatePhoneNumberOptions
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `MailSlurpClient::CreatePhoneNumberOptions` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `MailSlurpClient::CreatePhoneNumberOptions`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'phone_country') self.phone_country = attributes[:'phone_country'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'schedule') self.schedule = attributes[:'schedule'] end if attributes.key?(:'phone_number_endpoint_override') self.phone_number_endpoint_override = attributes[:'phone_number_endpoint_override'] end if attributes.key?(:'phone_number_variant') self.phone_number_variant = attributes[:'phone_number_variant'] end if attributes.key?(:'phone_provider') self.phone_provider = attributes[:'phone_provider'] end if attributes.key?(:'phone_line_filter') self.phone_line_filter = attributes[:'phone_line_filter'] end end |
Instance Attribute Details
#description ⇒ Object
Returns the value of attribute description.
21 22 23 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 21 def description @description end |
#name ⇒ Object
Returns the value of attribute name.
19 20 21 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 19 def name @name end |
#phone_country ⇒ Object
Returns the value of attribute phone_country.
17 18 19 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 17 def phone_country @phone_country end |
#phone_line_filter ⇒ Object
Line-quality preference for simple phone number provisioning
34 35 36 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 34 def phone_line_filter @phone_line_filter end |
#phone_number_endpoint_override ⇒ Object
Returns the value of attribute phone_number_endpoint_override.
27 28 29 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 27 def phone_number_endpoint_override @phone_number_endpoint_override end |
#phone_number_variant ⇒ Object
Returns the value of attribute phone_number_variant.
29 30 31 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 29 def phone_number_variant @phone_number_variant end |
#phone_provider ⇒ Object
Returns the value of attribute phone_provider.
31 32 33 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 31 def phone_provider @phone_provider end |
#schedule ⇒ Object
Returns the value of attribute schedule.
25 26 27 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 25 def schedule @schedule end |
#tags ⇒ Object
Returns the value of attribute tags.
23 24 25 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 23 def @tags end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 59 def self.attribute_map { :'phone_country' => :'phoneCountry', :'name' => :'name', :'description' => :'description', :'tags' => :'tags', :'schedule' => :'schedule', :'phone_number_endpoint_override' => :'phoneNumberEndpointOverride', :'phone_number_variant' => :'phoneNumberVariant', :'phone_provider' => :'phoneProvider', :'phone_line_filter' => :'phoneLineFilter' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
257 258 259 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 257 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 89 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 74 def self.openapi_types { :'phone_country' => :'String', :'name' => :'String', :'description' => :'String', :'tags' => :'Array<String>', :'schedule' => :'String', :'phone_number_endpoint_override' => :'String', :'phone_number_variant' => :'String', :'phone_provider' => :'String', :'phone_line_filter' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 228 def ==(o) return true if self.equal?(o) self.class == o.class && phone_country == o.phone_country && name == o.name && description == o.description && == o. && schedule == o.schedule && phone_number_endpoint_override == o.phone_number_endpoint_override && phone_number_variant == o.phone_number_variant && phone_provider == o.phone_provider && phone_line_filter == o.phone_line_filter end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 285 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model MailSlurpClient.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 354 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 264 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
244 245 246 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 244 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
250 251 252 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 250 def hash [phone_country, name, description, , schedule, phone_number_endpoint_override, phone_number_variant, phone_provider, phone_line_filter].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
150 151 152 153 154 155 156 157 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 150 def list_invalid_properties invalid_properties = Array.new if @phone_country.nil? invalid_properties.push('invalid value for "phone_country", phone_country cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
330 331 332 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 330 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 336 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
324 325 326 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 324 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/mailslurp_client/models/create_phone_number_options.rb', line 161 def valid? return false if @phone_country.nil? phone_country_validator = EnumAttributeValidator.new('String', ["US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]) return false unless phone_country_validator.valid?(@phone_country) schedule_validator = EnumAttributeValidator.new('String', ["MONTHLY", "YEARLY"]) return false unless schedule_validator.valid?(@schedule) phone_number_variant_validator = EnumAttributeValidator.new('String', ["LOCAL", "MOBILE", "TOLL_FREE"]) return false unless phone_number_variant_validator.valid?(@phone_number_variant) phone_provider_validator = EnumAttributeValidator.new('String', ["T1", "T2"]) return false unless phone_provider_validator.valid?(@phone_provider) phone_line_filter_validator = EnumAttributeValidator.new('String', ["ANY", "OTP_FRIENDLY", "NON_VOIP"]) return false unless phone_line_filter_validator.valid?(@phone_line_filter) true end |