Class: MailSlurpClient::EmailIntelligenceSignalsDto
- Inherits:
-
Object
- Object
- MailSlurpClient::EmailIntelligenceSignalsDto
- Defined in:
- lib/mailslurp_client/models/email_intelligence_signals_dto.rb
Overview
Computed signals for an email intelligence result.
Instance Attribute Summary collapse
-
#dns_a_record_present ⇒ Object
Returns the value of attribute dns_a_record_present.
-
#dns_mx_record_present ⇒ Object
Returns the value of attribute dns_mx_record_present.
-
#domain ⇒ Object
Returns the value of attribute domain.
-
#domain_age_hint_days ⇒ Object
Returns the value of attribute domain_age_hint_days.
-
#email_address ⇒ Object
Returns the value of attribute email_address.
-
#free_email_provider ⇒ Object
Returns the value of attribute free_email_provider.
-
#has_https_website ⇒ Object
Returns the value of attribute has_https_website.
-
#local_part ⇒ Object
Returns the value of attribute local_part.
-
#local_part_entropy ⇒ Object
Returns the value of attribute local_part_entropy.
-
#never_bounce_safe_to_send ⇒ Object
Returns the value of attribute never_bounce_safe_to_send.
-
#normalized_target ⇒ Object
Returns the value of attribute normalized_target.
-
#notes ⇒ Object
Returns the value of attribute notes.
-
#random_local_part ⇒ Object
Returns the value of attribute random_local_part.
-
#soa_record_present ⇒ Object
Returns the value of attribute soa_record_present.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EmailIntelligenceSignalsDto
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ EmailIntelligenceSignalsDto
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `MailSlurpClient::EmailIntelligenceSignalsDto` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `MailSlurpClient::EmailIntelligenceSignalsDto`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'normalized_target') self.normalized_target = attributes[:'normalized_target'] end if attributes.key?(:'email_address') self.email_address = attributes[:'email_address'] end if attributes.key?(:'domain') self.domain = attributes[:'domain'] end if attributes.key?(:'local_part') self.local_part = attributes[:'local_part'] end if attributes.key?(:'random_local_part') self.random_local_part = attributes[:'random_local_part'] end if attributes.key?(:'local_part_entropy') self.local_part_entropy = attributes[:'local_part_entropy'] end if attributes.key?(:'free_email_provider') self.free_email_provider = attributes[:'free_email_provider'] end if attributes.key?(:'has_https_website') self.has_https_website = attributes[:'has_https_website'] end if attributes.key?(:'dns_a_record_present') self.dns_a_record_present = attributes[:'dns_a_record_present'] end if attributes.key?(:'dns_mx_record_present') self.dns_mx_record_present = attributes[:'dns_mx_record_present'] end if attributes.key?(:'soa_record_present') self.soa_record_present = attributes[:'soa_record_present'] end if attributes.key?(:'domain_age_hint_days') self.domain_age_hint_days = attributes[:'domain_age_hint_days'] end if attributes.key?(:'never_bounce_safe_to_send') self.never_bounce_safe_to_send = attributes[:'never_bounce_safe_to_send'] end if attributes.key?(:'notes') if (value = attributes[:'notes']).is_a?(Array) self.notes = value end end end |
Instance Attribute Details
#dns_a_record_present ⇒ Object
Returns the value of attribute dns_a_record_present.
34 35 36 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 34 def dns_a_record_present @dns_a_record_present end |
#dns_mx_record_present ⇒ Object
Returns the value of attribute dns_mx_record_present.
36 37 38 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 36 def dns_mx_record_present @dns_mx_record_present end |
#domain ⇒ Object
Returns the value of attribute domain.
22 23 24 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 22 def domain @domain end |
#domain_age_hint_days ⇒ Object
Returns the value of attribute domain_age_hint_days.
40 41 42 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 40 def domain_age_hint_days @domain_age_hint_days end |
#email_address ⇒ Object
Returns the value of attribute email_address.
20 21 22 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 20 def email_address @email_address end |
#free_email_provider ⇒ Object
Returns the value of attribute free_email_provider.
30 31 32 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 30 def free_email_provider @free_email_provider end |
#has_https_website ⇒ Object
Returns the value of attribute has_https_website.
32 33 34 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 32 def has_https_website @has_https_website end |
#local_part ⇒ Object
Returns the value of attribute local_part.
24 25 26 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 24 def local_part @local_part end |
#local_part_entropy ⇒ Object
Returns the value of attribute local_part_entropy.
28 29 30 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 28 def local_part_entropy @local_part_entropy end |
#never_bounce_safe_to_send ⇒ Object
Returns the value of attribute never_bounce_safe_to_send.
42 43 44 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 42 def never_bounce_safe_to_send @never_bounce_safe_to_send end |
#normalized_target ⇒ Object
Returns the value of attribute normalized_target.
18 19 20 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 18 def normalized_target @normalized_target end |
#notes ⇒ Object
Returns the value of attribute notes.
44 45 46 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 44 def notes @notes end |
#random_local_part ⇒ Object
Returns the value of attribute random_local_part.
26 27 28 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 26 def random_local_part @random_local_part end |
#soa_record_present ⇒ Object
Returns the value of attribute soa_record_present.
38 39 40 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 38 def soa_record_present @soa_record_present end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 47 def self.attribute_map { :'normalized_target' => :'normalizedTarget', :'email_address' => :'emailAddress', :'domain' => :'domain', :'local_part' => :'localPart', :'random_local_part' => :'randomLocalPart', :'local_part_entropy' => :'localPartEntropy', :'free_email_provider' => :'freeEmailProvider', :'has_https_website' => :'hasHttpsWebsite', :'dns_a_record_present' => :'dnsARecordPresent', :'dns_mx_record_present' => :'dnsMxRecordPresent', :'soa_record_present' => :'soaRecordPresent', :'domain_age_hint_days' => :'domainAgeHintDays', :'never_bounce_safe_to_send' => :'neverBounceSafeToSend', :'notes' => :'notes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
241 242 243 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 241 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 87 def self.openapi_nullable Set.new([ :'email_address', :'local_part', :'random_local_part', :'local_part_entropy', :'free_email_provider', :'has_https_website', :'dns_a_record_present', :'dns_mx_record_present', :'soa_record_present', :'domain_age_hint_days', :'never_bounce_safe_to_send', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 67 def self.openapi_types { :'normalized_target' => :'String', :'email_address' => :'String', :'domain' => :'String', :'local_part' => :'String', :'random_local_part' => :'Boolean', :'local_part_entropy' => :'Float', :'free_email_provider' => :'Boolean', :'has_https_website' => :'Boolean', :'dns_a_record_present' => :'Boolean', :'dns_mx_record_present' => :'Boolean', :'soa_record_present' => :'Boolean', :'domain_age_hint_days' => :'Integer', :'never_bounce_safe_to_send' => :'Boolean', :'notes' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 207 def ==(o) return true if self.equal?(o) self.class == o.class && normalized_target == o.normalized_target && email_address == o.email_address && domain == o.domain && local_part == o.local_part && random_local_part == o.random_local_part && local_part_entropy == o.local_part_entropy && free_email_provider == o.free_email_provider && has_https_website == o.has_https_website && dns_a_record_present == o.dns_a_record_present && dns_mx_record_present == o.dns_mx_record_present && soa_record_present == o.soa_record_present && domain_age_hint_days == o.domain_age_hint_days && never_bounce_safe_to_send == o.never_bounce_safe_to_send && notes == o.notes end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 269 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model MailSlurpClient.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 338 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 248 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
228 229 230 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 228 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
234 235 236 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 234 def hash [normalized_target, email_address, domain, local_part, random_local_part, local_part_entropy, free_email_provider, has_https_website, dns_a_record_present, dns_mx_record_present, soa_record_present, domain_age_hint_days, never_bounce_safe_to_send, notes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 179 def list_invalid_properties invalid_properties = Array.new if @normalized_target.nil? invalid_properties.push('invalid value for "normalized_target", normalized_target cannot be nil.') end if @domain.nil? invalid_properties.push('invalid value for "domain", domain cannot be nil.') end if @notes.nil? invalid_properties.push('invalid value for "notes", notes cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
314 315 316 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 314 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 320 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
308 309 310 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 308 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
198 199 200 201 202 203 |
# File 'lib/mailslurp_client/models/email_intelligence_signals_dto.rb', line 198 def valid? return false if @normalized_target.nil? return false if @domain.nil? return false if @notes.nil? true end |