Class: MailSlurpClient::InboxForwarderDto

Inherits:
Object
  • Object
show all
Defined in:
lib/mailslurp_client/models/inbox_forwarder_dto.rb

Overview

Inbox forwarder. Describes how an inbox will forward matching emails to designated recipients.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InboxForwarderDto

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `MailSlurpClient::InboxForwarderDto` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `MailSlurpClient::InboxForwarderDto`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'inbox_id')
    self.inbox_id = attributes[:'inbox_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'field')
    self.field = attributes[:'field']
  end

  if attributes.key?(:'match')
    self.match = attributes[:'match']
  end

  if attributes.key?(:'forward_to_recipients')
    if (value = attributes[:'forward_to_recipients']).is_a?(Array)
      self.forward_to_recipients = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'should')
    self.should = attributes[:'should']
  end

  if attributes.key?(:'match_options')
    self.match_options = attributes[:'match_options']
  end

  if attributes.key?(:'attachment_text_extraction_method')
    self.attachment_text_extraction_method = attributes[:'attachment_text_extraction_method']
  end
end

Instance Attribute Details

#attachment_text_extraction_methodObject

Method for extracting text from attachments.



42
43
44
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 42

def attachment_text_extraction_method
  @attachment_text_extraction_method
end

#created_atObject

Returns the value of attribute created_at.



34
35
36
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 34

def created_at
  @created_at
end

#fieldObject

Which field to match against



26
27
28
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 26

def field
  @field
end

#forward_to_recipientsObject

Who to send forwarded email to



32
33
34
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 32

def forward_to_recipients
  @forward_to_recipients
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 18

def id
  @id
end

#inbox_idObject

Returns the value of attribute inbox_id.



20
21
22
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 20

def inbox_id
  @inbox_id
end

#matchObject

Pattern to apply to field



29
30
31
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 29

def match
  @match
end

#match_optionsObject

Returns the value of attribute match_options.



39
40
41
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 39

def match_options
  @match_options
end

#nameObject

Name of inbox forwarder



23
24
25
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 23

def name
  @name
end

#shouldObject

Comparison mode for inbox automation matching.



37
38
39
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 37

def should
  @should
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 67

def self.attribute_map
  {
    :'id' => :'id',
    :'inbox_id' => :'inboxId',
    :'name' => :'name',
    :'field' => :'field',
    :'match' => :'match',
    :'forward_to_recipients' => :'forwardToRecipients',
    :'created_at' => :'createdAt',
    :'should' => :'should',
    :'match_options' => :'matchOptions',
    :'attachment_text_extraction_method' => :'attachmentTextExtractionMethod'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



265
266
267
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 265

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
103
104
105
106
107
108
109
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 99

def self.openapi_nullable
  Set.new([
    :'inbox_id',
    :'name',
    :'field',
    :'match',
    :'should',
    :'match_options',
    :'attachment_text_extraction_method'
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 83

def self.openapi_types
  {
    :'id' => :'String',
    :'inbox_id' => :'String',
    :'name' => :'String',
    :'field' => :'String',
    :'match' => :'String',
    :'forward_to_recipients' => :'Array<String>',
    :'created_at' => :'DateTime',
    :'should' => :'String',
    :'match_options' => :'InboxAutomationMatchOptions',
    :'attachment_text_extraction_method' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 235

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      inbox_id == o.inbox_id &&
      name == o.name &&
      field == o.field &&
      match == o.match &&
      forward_to_recipients == o.forward_to_recipients &&
      created_at == o.created_at &&
      should == o.should &&
      match_options == o.match_options &&
      attachment_text_extraction_method == o.attachment_text_extraction_method
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 293

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    MailSlurpClient.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 362

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 272

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


252
253
254
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 252

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



258
259
260
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 258

def hash
  [id, inbox_id, name, field, match, forward_to_recipients, created_at, should, match_options, attachment_text_extraction_method].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 171

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @forward_to_recipients.nil?
    invalid_properties.push('invalid value for "forward_to_recipients", forward_to_recipients cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



338
339
340
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 338

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 344

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



332
333
334
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 332

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/mailslurp_client/models/inbox_forwarder_dto.rb', line 190

def valid?
  return false if @id.nil?
  field_validator = EnumAttributeValidator.new('String', ["RECIPIENTS", "SENDER", "SUBJECT", "ATTACHMENTS", "ATTACHMENT_FILENAME", "ATTACHMENT_TEXT"])
  return false unless field_validator.valid?(@field)
  return false if @forward_to_recipients.nil?
  return false if @created_at.nil?
  should_validator = EnumAttributeValidator.new('String', ["WILDCARD", "MATCH", "CONTAIN", "EQUAL"])
  return false unless should_validator.valid?(@should)
  attachment_text_extraction_method_validator = EnumAttributeValidator.new('String', ["AUTO", "NATIVE", "OCR", "LLM", "OCR_THEN_LLM"])
  return false unless attachment_text_extraction_method_validator.valid?(@attachment_text_extraction_method)
  true
end